@@ -3,7 +3,7 @@ package GUIDeFATE;
    use strict;
    use warnings;
    
-   our $VERSION = '0.10';
+   our $VERSION = '0.11';
    
    use Exporter 'import';
    
@@ -111,7 +111,7 @@ sub convert{
 			$fh++;
 			if ($ps  && ($fh-2)) {
 				$content=~s/^\s+|\s+$//g;
-				$log="SubPanel '$panelType' Id $bid found position  $ps height $fh width $fl at row $l with content $content \n";##
+				$log="SubPanel '$panelType' Id ".($bid+1)." found position  $ps height $fh width $fl at row $l with content $content \n";##
 				if ($verbose){ print $log; }
 				if ($auto){ $autoGen.="#".$log; }
 				addWidget(["sp",$bid,$panelType,$content,[$winScale*($ps*2-1),$winScale*$l*4],[$winScale*($fl*2+3),$winScale*$fh*4]]);
@@ -153,11 +153,15 @@ sub convert{
 		  $tmp=~s/^(\|)|(\|)$//g;                                     #remove starting and ending border
 		  $tmp=~s/^(\s+)|(\s+)$//g;                                   #remove spaces                                 
 		  if (length $tmp){
-			  $log= "Static text '".$tmp."'  with id stattext$bid\n"; ##
-			  if ($verbose){ print $log; }
-			  if ($auto){ $autoGen.="#".$log; }
-		      $line=~m/\Q$tmp\E/;my $ps=length($`);
-		      addWidget(["stattext",$bid++, $tmp,[$winScale*($ps*2-1),$winScale*$l*4]]);
+			  my @texts=split(/\s{2,}/,$tmp); # two or more spaces means different static text
+			  foreach my $stxt (@texts){
+			    $log= "Static text '".$stxt."'  with id stattext$bid\n"; ##
+			    if ($verbose){ print $log; }
+			    if ($auto){ $autoGen.="#".$log; }
+		        $line=~m/\Q$stxt\E/;my $ps=length($`);
+		        $line=~s/(\Q$stxt\E)/" " x length($1)/e;
+		        addWidget(["stattext",$bid++, $stxt,[$winScale*($ps*2-1),$winScale*$l*4]]);
+			  }
 		  }
 	     }
 		$l++;		
